//
//  UIViewControllerExtensions.swift
//  EinProzent
//
//  Created by Johannes Luderschmidt on 17.09.15.
//  Copyright © 2015 Topalsson. All rights reserved.
//

import Foundation
import UIKit
import ObjectiveC
import MapKit

private var LocationAuthorizationManagerKey: UInt8 = 0

extension UIViewController{
    var locationManager:CLLocationManager? {
        get{
            let storedObj = objc_getAssociatedObject(self, &LocationAuthorizationManagerKey)
            let locationManager = storedObj as? CLLocationManager
            return locationManager
        }
        set(newValue){
            objc_setAssociatedObject(self, &LocationAuthorizationManagerKey, newValue, objc_AssociationPolicy.OBJC_ASSOCIATION_RETAIN_NONATOMIC)
        }
    }
    
    func initializeLocationAuthorization(){
        self.locationManager = CLLocationManager()
        locationManager!.delegate = self as? CLLocationManagerDelegate
    }
    
    func checkLocationAuthorizationAlwaysStatus() -> Bool{
        var locationAuthorized = true
        if self.locationManager == nil {
            self.initializeLocationAuthorization()
        }
        
        if CLLocationManager.authorizationStatus().rawValue != CLAuthorizationStatus.AuthorizedAlways.rawValue{
            self.locationManager?.requestAlwaysAuthorization()
            if CLLocationManager.authorizationStatus().rawValue < CLAuthorizationStatus.Denied.rawValue{
                locationAuthorized = false
            }
        }
        
        return locationAuthorized
    }
    
    func checkLocationAuthorizationWhenInUseStatus() -> Bool{
        var locationAuthorized = true
        if self.locationManager == nil {
            self.initializeLocationAuthorization()
        }
        
        if CLLocationManager.authorizationStatus().rawValue < CLAuthorizationStatus.AuthorizedAlways.rawValue{
            self.locationManager?.requestWhenInUseAuthorization()
            if CLLocationManager.authorizationStatus().rawValue < CLAuthorizationStatus.Denied.rawValue{
                locationAuthorized = false
            }
        }
        
        return locationAuthorized
    }
    
    
}